==> GWmodel_1.1-9.tar.gz: GWmodel/man/gwr.cv.contrib.Rd <==
\name{gwr.cv.contrib}
\alias{gwr.cv.contrib}
\title{Cross-validation data at each observation location for a basic GWR model}
\description{
This function finds the cross-validation data at each observation location for a basic GWR model with a specified bandwidth.  Can be used to detect outliers.
}
\usage{
gwr.cv.contrib(bw, X, Y, kernel,adaptive, dp.locat, p, theta, longlat,dMat)
}

\arguments{
  \item{bw}{bandwidth used in the weighting function;fixed (distance) or adaptive bandwidth(number of nearest neighbours)}
  \item{X}{a numeric matrix of independent samples with ones for the 1st column}
  \item{Y}{a one-column vector of dependent samples}
  \item{kernel}{function chosen as follows:
  
                gaussian: wgt = exp(-.5*(vdist/bw)^2);
                
                exponential: wgt = exp(-vdist/bw);
                
                bisquare: wgt = (1-(vdist/bw)^2)^2 if vdist < bw, wgt=0 otherwise;
                
                tricube: wgt = (1-(vdist/bw)^3)^3 if vdist < bw, wgt=0 otherwise; 
                
                boxcar: wgt=1 if dist < bw, wgt=0 otherwise}
  \item{adaptive}{if TRUE calculate an adaptive kernel where the bandwidth (bw) corresponds to the number of nearest neighbours (i.e. adaptive distance); default is FALSE, where a fixed kernel is found (bandwidth is a fixed distance)}
  \item{dp.locat}{a two-column numeric array of observation coordinates}
  \item{p}{the power of the Minkowski distance, default is 2, i.e. the Euclidean distance}
  \item{theta}{an angle in radians to rotate the coordinate system, default is 0}
  \item{longlat}{if TRUE, great circle distances will be calculated}
  \item{dMat}{a pre-specified distance matrix, it can be calculated by the function \code{\link{gw.dist}}}
}
\value{
  \item{CV}{a data vector consisting of squared residuals, whose mean is the cross-validation score for the specified bandwidth.}
}
\author{Binbin Lu \email{lubinbin220@gmail.com}}
\references{Harris P, Clarke A, Juggins S, Brunsdon C, Charlton M (2013) Investigating change in the spatial structure of environmental data using a non-stationary principal components analysis.  In review}
\keyword{cv, GWR}

==> GWmodel_1.2-2.tar.gz: GWmodel/man/gwr.cv.contrib.Rd <==
\name{gwr.cv.contrib}
\alias{gwr.cv.contrib}
\title{Cross-validation data at each observation location for a basic GWR model}
\description{
This function finds the cross-validation data at each observation location for a basic GWR model with a specified bandwidth.  Can be used to detect outliers.
}
\usage{
gwr.cv.contrib(bw, X, Y, kernel="bisquare",adaptive=FALSE, dp.locat, p=2, 
               theta=0, longlat=F,dMat)
}

\arguments{
  \item{bw}{bandwidth used in the weighting function;fixed (distance) or adaptive bandwidth(number of nearest neighbours)}
  \item{X}{a numeric matrix of the independent data with an extra column of \dQuote{ones} for the 1st column}
  \item{Y}{a column vector of the dependent data}
  \item{kernel}{function chosen as follows:
  
                gaussian: wgt = exp(-.5*(vdist/bw)^2);
                
                exponential: wgt = exp(-vdist/bw);
                
                bisquare: wgt = (1-(vdist/bw)^2)^2 if vdist < bw, wgt=0 otherwise;
                
                tricube: wgt = (1-(vdist/bw)^3)^3 if vdist < bw, wgt=0 otherwise; 
                
                boxcar: wgt=1 if dist < bw, wgt=0 otherwise}
  \item{adaptive}{if TRUE calculate an adaptive kernel where the bandwidth (bw) corresponds to the number of nearest neighbours (i.e. adaptive distance); default is FALSE, where a fixed kernel is found (bandwidth is a fixed distance)}
  \item{dp.locat}{a two-column numeric array of observation coordinates}
  \item{p}{the power of the Minkowski distance, default is 2, i.e. the Euclidean distance}
  \item{theta}{an angle in radians to rotate the coordinate system, default is 0}
  \item{longlat}{if TRUE, great circle distances will be calculated}
  \item{dMat}{a pre-specified distance matrix, it can be calculated by the function \code{\link{gw.dist}}}
}
\value{
  \item{CV}{a data vector consisting of squared residuals, whose sum is the cross-validation score for the specified bandwidth.}
}
\author{Binbin Lu \email{lubinbin220@gmail.com}}
\keyword{cv, GWR}
